[java-identity-provider COMMIT] in /trunk: idp-session-api/src/main/java/net/shibboleth/idp/session/SessionManager.ja...

noreply at shibboleth.net noreply at shibboleth.net
Mon Oct 7 23:13:37 EDT 2013


Author: scantor
Date: Mon Oct  7 23:13:37 2013
New Revision: 4837

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=4837&view=rev
Log:
Add profile request context to session manager API.

Added:
    trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/criterion/HttpServletRequestCriterion.java   (with props)
Modified:
    trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/SessionManager.java
    trunk/idp-session-impl/pom.xml
    trunk/idp-session-impl/src/main/java/net/shibboleth/idp/session/impl/StorageBackedSessionManager.java
    trunk/idp-session-impl/src/test/java/net/shibboleth/idp/session/impl/StorageBackedSessionManagerTest.java

Modified: trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/SessionManager.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/SessionManager.java?rev=4837&r1=4836&r2=4837&view=diff
==============================================================================
--- trunk/idp-session-impl/src/main/java/net/shibboleth/idp/session/impl/StorageBackedSessionManager.java (original)
+++ trunk/idp-session-impl/src/main/java/net/shibboleth/idp/session/impl/StorageBackedSessionManager.java Mon Oct  7 23:13:37 2013
@@ -25,6 +25,7 @@
 import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
 
+import org.opensaml.profile.context.ProfileRequestContext;
 import org.opensaml.storage.ClientStorageService;
 import org.opensaml.storage.StorageRecord;
 import org.opensaml.storage.StorageSerializer;
@@ -359,9 +360,11 @@
     }
 
     /** {@inheritDoc} */
-    @Nonnull public IdPSession createSession(@Nonnull @NotEmpty final String principalName,
-            @Nullable final String bindToAddress) throws SessionException {
+    @Nonnull public IdPSession createSession(@Nonnull final ProfileRequestContext profileRequestContext,

[... 185 lines stripped ...]


More information about the commits mailing list
--- trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/SessionManager.java (original)
+++ trunk/idp-session-api/src/main/java/net/shibboleth/idp/session/SessionManager.java Mon Oct  7 23:13:37 2013
@@ -21,6 +21,8 @@
 import javax.annotation.Nullable;
 import javax.annotation.concurrent.ThreadSafe;
 
+import org.opensaml.profile.context.ProfileRequestContext;
+
 import net.shibboleth.utilities.java.support.annotation.constraint.NotEmpty;
 import net.shibboleth.utilities.java.support.component.DestructableComponent;
 import net.shibboleth.utilities.java.support.component.IdentifiableComponent;
@@ -37,24 +39,30 @@
     /**
      * Create and return a new {@link IdPSession} object for a subject.
      * 
      * <p>The new session object should be appropriately persisted by the time it's returned.</p>
      * 
+     * @param profileRequestContext profile request context
      * @param principalName canonical name of the subject of the session
      * @param bindToAddress an initial client address to bind the session to
      * 
      * @return  the newly created session
      * @throws SessionException if the session cannot be created
      */
-    @Nonnull public IdPSession createSession(@Nonnull @NotEmpty final String principalName,
-            @Nullable final String bindToAddress) throws SessionException;
+    @Nonnull public IdPSession createSession(@Nonnull final ProfileRequestContext profileRequestContext,
+            @Nonnull @NotEmpty final String principalName, @Nullable final String bindToAddress)
+                    throws SessionException;
     
     /**
      * Invalidates or otherwise removes a session from persistent storage.
      * 
+     * @param profileRequestContext profile request context
      * @param sessionId the unique ID of the session to destroy
      * 
      * @throws SessionException if the session cannot be destroyed
      */
-    public void destroySession(@Nonnull @NotEmpty final String sessionId) throws SessionException;
+    public void destroySession(@Nonnull final ProfileRequestContext profileRequestContext,
+            @Nonnull @NotEmpty final String sessionId) throws SessionException;
 
 }
@@ -37,24 +39,30 @@
      * Create and return a new {@link IdPSession} object for a subject.
      * 
-     * <p>The new session object should be appropriately persisted by the time it's returned.</p>
+     * <p>The new session object will be appropriately persisted and/or bound to the
+     * {@link ProfileRequestContext} by the time it's returned.</p>
      * 
@@ -37,24 +39,30 @@
     
     /**
-     * Invalidates or otherwise removes a session from persistent storage.
+     * Invalidates or otherwise removes a session from persistent storage and/or unbinds it
+     * from a {@link ProfileRequestContext}.
      * 

Modified: trunk/idp-session-impl/pom.xml
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-session-impl/pom.xml?rev=4837&r1=4836&r2=4837&view=diff
==============================================================================
Binary files - no diff available.

Modified: trunk/idp-session-impl/src/main/java/net/shibboleth/idp/session/impl/StorageBackedSessionManager.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-session-impl/src/main/java/net/shibboleth/idp/session/impl/StorageBackedSessionManager.java?rev=4837&r1=4836&r2=4837&view=diff
==============================================================================